[llvm] r289854 - Fix some remaining documentation references to MSVC 2013

Reid Kleckner via llvm-commits llvm-commits at lists.llvm.org
Thu Dec 15 11:08:03 PST 2016


Author: rnk
Date: Thu Dec 15 13:08:02 2016
New Revision: 289854

URL: http://llvm.org/viewvc/llvm-project?rev=289854&view=rev
Log:
Fix some remaining documentation references to MSVC 2013

MSVC 2015 has been the minimum supported version of VS since October.

Differential Revision: https://reviews.llvm.org/D25710

Modified:
    llvm/trunk/cmake/modules/CheckCompilerVersion.cmake
    llvm/trunk/docs/CodingStandards.rst
    llvm/trunk/docs/GettingStarted.rst

Modified: llvm/trunk/cmake/modules/CheckCompilerVersion.cmake
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/cmake/modules/CheckCompilerVersion.cmake?rev=289854&r1=289853&r2=289854&view=diff
==============================================================================
--- llvm/trunk/docs/CodingStandards.rst (original)
+++ llvm/trunk/docs/CodingStandards.rst Thu Dec 15 13:08:02 2016
@@ -131,9 +131,8 @@ unlikely to be supported by our host com
 * Delegating constructors: N1986_
 * Default member initializers (non-static data member initializers): N2756_
 
-  * Only use these for scalar members that would otherwise be left
-    uninitialized. Non-scalar members generally have appropriate default
-    constructors.
+  * Feel free to use these wherever they make sense and where the `=`
+    syntax is allowed. Don't use braced initialization syntax.
 
 .. _N2118: http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2006/n2118.html
 .. _N2439: http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2007/n2439.htm

Modified: llvm/trunk/docs/GettingStarted.rst
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/docs/GettingStarted.rst?rev=289854&r1=289853&r2=289854&view=diff
==============================================================================
--- llvm/trunk/docs/GettingStarted.rst (original)
+++ llvm/trunk/docs/GettingStarted.rst Thu Dec 15 13:08:02 2016
@@ -262,7 +262,7 @@ our build systems:
 
 * Clang 3.1
 * GCC 4.8
-* Visual Studio 2015
+* Visual Studio 2015 (Update 3)
 
 Anything older than these toolchains *may* work, but will require forcing the
 build system with a special option and is not really a supported host platform.




More information about the llvm-commits mailing list
--- llvm/trunk/cmake/modules/CheckCompilerVersion.cmake (original)
+++ llvm/trunk/cmake/modules/CheckCompilerVersion.cmake Thu Dec 15 13:08:02 2016
@@ -1,5 +1,5 @@
 # Check if the host compiler is new enough. LLVM requires at least GCC 4.8,
 # MSVC 2013, or Clang 3.1.
 
 include(CheckCXXSourceCompiles)
 
@@ -17,8 +17,8 @@ if(NOT DEFINED LLVM_COMPILER_CHECKED)
       endif()
 
       if (CMAKE_CXX_SIMULATE_ID MATCHES "MSVC")
-        if (CMAKE_CXX_SIMULATE_VERSION VERSION_LESS 18.0)
-          message(FATAL_ERROR "Host Clang must have at least -fms-compatibility-version=18.0")
+        if (CMAKE_CXX_SIMULATE_VERSION VERSION_LESS 19.0)
+          message(FATAL_ERROR "Host Clang must have at least -fms-compatibility-version=19.0")
         endif()
         set(CLANG_CL 1)
       elseif(NOT LLVM_ENABLE_LIBCXX)
@@ -41,10 +41,10 @@ int main() { return (float)x; }"
         set(CMAKE_REQUIRED_LIBRARIES ${OLD_CMAKE_REQUIRED_LIBRARIES})
       endif()
     elseif(CMAKE_CXX_COMPILER_ID MATCHES "MSVC")
-      if(CMAKE_CXX_COMPILER_VERSION VERSION_LESS 18.0)
-        message(FATAL_ERROR "Host Visual Studio must be at least 2013")
-      elseif(CMAKE_CXX_COMPILER_VERSION VERSION_LESS 18.0.31101)
-        message(WARNING "Host Visual Studio should at least be 2013 Update 4 (MSVC 18.0.31101)"
+      if(CMAKE_CXX_COMPILER_VERSION VERSION_LESS 19.0)
+        message(FATAL_ERROR "Host Visual Studio must be at least 2015")
+      elseif(CMAKE_CXX_COMPILER_VERSION VERSION_LESS 19.00.24215.1)
+        message(WARNING "Host Visual Studio should at least be 2015 Update 3 (MSVC 19.00.24215.1)"
           "  due to miscompiles from earlier versions")
       endif()
     endif()
@@ -1,5 +1,5 @@
 # Check if the host compiler is new enough. LLVM requires at least GCC 4.8,
-# MSVC 2013, or Clang 3.1.
+# MSVC 2015 (Update 3), or Clang 3.1.
 
 include(CheckCXXSourceCompiles)

Modified: llvm/trunk/docs/CodingStandards.rst
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/docs/CodingStandards.rst?rev=289854&r1=289853&r2=289854&view=diff
==============================================================================